# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/logic.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/logic.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\nLogicProto'),
  serialized_pb=_b('\n\x14protobuf/logic.proto\x12\x0egrakn.protocol\"\xaf\x06\n\x0cLogicManager\x1a\xf9\x01\n\x03Req\x12L\n\x0cget_rule_req\x18\x01 \x01(\x0b\x32(.grakn.protocol.LogicManager.GetRule.ReqH\x00R\ngetRuleReq\x12L\n\x0cput_rule_req\x18\x02 \x01(\x0b\x32(.grakn.protocol.LogicManager.PutRule.ReqH\x00R\nputRuleReq\x12O\n\rget_rules_req\x18\x03 \x01(\x0b\x32).grakn.protocol.LogicManager.GetRules.ReqH\x00R\x0bgetRulesReqB\x05\n\x03req\x1a\xf9\x01\n\x03Res\x12L\n\x0cget_rule_res\x18\x01 \x01(\x0b\x32(.grakn.protocol.LogicManager.GetRule.ResH\x00R\ngetRuleRes\x12L\n\x0cput_rule_res\x18\x02 \x01(\x0b\x32(.grakn.protocol.LogicManager.PutRule.ResH\x00R\nputRuleRes\x12O\n\rget_rules_res\x18\x03 \x01(\x0b\x32).grakn.protocol.LogicManager.GetRules.ResH\x00R\x0bgetRulesResB\x05\n\x03res\x1a`\n\x07GetRule\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a\x38\n\x03Res\x12*\n\x04rule\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.RuleH\x00R\x04ruleB\x05\n\x03res\x1a\x7f\n\x07PutRule\x1a\x43\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x12\n\x04when\x18\x02 \x01(\tR\x04when\x12\x12\n\x04then\x18\x03 \x01(\tR\x04then\x1a/\n\x03Res\x12(\n\x04rule\x18\x01 \x01(\x0b\x32\x14.grakn.protocol.RuleR\x04rule\x1a\x44\n\x08GetRules\x1a\x05\n\x03Req\x1a\x31\n\x03Res\x12*\n\x05rules\x18\x01 \x03(\x0b\x32\x14.grakn.protocol.RuleR\x05rules\"\xfa\x03\n\x04Rule\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12\x12\n\x04when\x18\x02 \x01(\tR\x04when\x12\x12\n\x04then\x18\x03 \x01(\tR\x04then\x1a\xbf\x01\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x12I\n\x0frule_delete_req\x18\x64 \x01(\x0b\x32\x1f.grakn.protocol.Rule.Delete.ReqH\x00R\rruleDeleteReq\x12P\n\x12rule_set_label_req\x18\x65 \x01(\x0b\x32!.grakn.protocol.Rule.SetLabel.ReqH\x00R\x0fruleSetLabelReqB\x05\n\x03req\x1a\xa9\x01\n\x03Res\x12I\n\x0frule_delete_res\x18\x64 \x01(\x0b\x32\x1f.grakn.protocol.Rule.Delete.ResH\x00R\rruleDeleteRes\x12P\n\x12rule_set_label_res\x18\x65 \x01(\x0b\x32!.grakn.protocol.Rule.SetLabel.ResH\x00R\x0fruleSetLabelResB\x05\n\x03res\x1a\x16\n\x06\x44\x65lete\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1a.\n\x08SetLabel\x1a\x1b\n\x03Req\x12\x14\n\x05label\x18\x01 \x01(\tR\x05label\x1a\x05\n\x03ResB\x1c\n\x0egrakn.protocolB\nLogicProtob\x06proto3')
)




_LOGICMANAGER_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.LogicManager.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_rule_req', full_name='grakn.protocol.LogicManager.Req.get_rule_req', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getRuleReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_rule_req', full_name='grakn.protocol.LogicManager.Req.put_rule_req', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putRuleReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_rules_req', full_name='grakn.protocol.LogicManager.Req.get_rules_req', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getRulesReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.LogicManager.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=58,
  serialized_end=307,
)

_LOGICMANAGER_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.LogicManager.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_rule_res', full_name='grakn.protocol.LogicManager.Res.get_rule_res', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getRuleRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_rule_res', full_name='grakn.protocol.LogicManager.Res.put_rule_res', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='putRuleRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_rules_res', full_name='grakn.protocol.LogicManager.Res.get_rules_res', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getRulesRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.LogicManager.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=310,
  serialized_end=559,
)

_LOGICMANAGER_GETRULE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.LogicManager.GetRule.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.LogicManager.GetRule.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=599,
)

_LOGICMANAGER_GETRULE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.LogicManager.GetRule.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='grakn.protocol.LogicManager.GetRule.Res.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rule', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.LogicManager.GetRule.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=601,
  serialized_end=657,
)

_LOGICMANAGER_GETRULE = _descriptor.Descriptor(
  name='GetRule',
  full_name='grakn.protocol.LogicManager.GetRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_LOGICMANAGER_GETRULE_REQ, _LOGICMANAGER_GETRULE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=657,
)

_LOGICMANAGER_PUTRULE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.LogicManager.PutRule.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.LogicManager.PutRule.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='when', full_name='grakn.protocol.LogicManager.PutRule.Req.when', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='when', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='then', full_name='grakn.protocol.LogicManager.PutRule.Req.then', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='then', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=737,
)

_LOGICMANAGER_PUTRULE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.LogicManager.PutRule.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='grakn.protocol.LogicManager.PutRule.Res.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rule', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=739,
  serialized_end=786,
)

_LOGICMANAGER_PUTRULE = _descriptor.Descriptor(
  name='PutRule',
  full_name='grakn.protocol.LogicManager.PutRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_LOGICMANAGER_PUTRULE_REQ, _LOGICMANAGER_PUTRULE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=786,
)

_LOGICMANAGER_GETRULES_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.LogicManager.GetRules.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=63,
)

_LOGICMANAGER_GETRULES_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.LogicManager.GetRules.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='grakn.protocol.LogicManager.GetRules.Res.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rules', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=856,
)

_LOGICMANAGER_GETRULES = _descriptor.Descriptor(
  name='GetRules',
  full_name='grakn.protocol.LogicManager.GetRules',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_LOGICMANAGER_GETRULES_REQ, _LOGICMANAGER_GETRULES_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=856,
)

_LOGICMANAGER = _descriptor.Descriptor(
  name='LogicManager',
  full_name='grakn.protocol.LogicManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_LOGICMANAGER_REQ, _LOGICMANAGER_RES, _LOGICMANAGER_GETRULE, _LOGICMANAGER_PUTRULE, _LOGICMANAGER_GETRULES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=856,
)


_RULE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Rule.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.Rule.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_delete_req', full_name='grakn.protocol.Rule.Req.rule_delete_req', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleDeleteReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_set_label_req', full_name='grakn.protocol.Rule.Req.rule_set_label_req', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleSetLabelReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Rule.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=930,
  serialized_end=1121,
)

_RULE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Rule.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_delete_res', full_name='grakn.protocol.Rule.Res.rule_delete_res', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleDeleteRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_set_label_res', full_name='grakn.protocol.Rule.Res.rule_set_label_res', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleSetLabelRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Rule.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1124,
  serialized_end=1293,
)

_RULE_DELETE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Rule.Delete.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=63,
)

_RULE_DELETE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Rule.Delete.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=315,
)

_RULE_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='grakn.protocol.Rule.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RULE_DELETE_REQ, _RULE_DELETE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1317,
)

_RULE_SETLABEL_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Rule.SetLabel.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.Rule.SetLabel.Req.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=599,
)

_RULE_SETLABEL_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Rule.SetLabel.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=315,
)

_RULE_SETLABEL = _descriptor.Descriptor(
  name='SetLabel',
  full_name='grakn.protocol.Rule.SetLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RULE_SETLABEL_REQ, _RULE_SETLABEL_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1365,
)

_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='grakn.protocol.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='grakn.protocol.Rule.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='label', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='when', full_name='grakn.protocol.Rule.when', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='when', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='then', full_name='grakn.protocol.Rule.then', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='then', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RULE_REQ, _RULE_RES, _RULE_DELETE, _RULE_SETLABEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=1365,
)

_LOGICMANAGER_REQ.fields_by_name['get_rule_req'].message_type = _LOGICMANAGER_GETRULE_REQ
_LOGICMANAGER_REQ.fields_by_name['put_rule_req'].message_type = _LOGICMANAGER_PUTRULE_REQ
_LOGICMANAGER_REQ.fields_by_name['get_rules_req'].message_type = _LOGICMANAGER_GETRULES_REQ
_LOGICMANAGER_REQ.containing_type = _LOGICMANAGER
_LOGICMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _LOGICMANAGER_REQ.fields_by_name['get_rule_req'])
_LOGICMANAGER_REQ.fields_by_name['get_rule_req'].containing_oneof = _LOGICMANAGER_REQ.oneofs_by_name['req']
_LOGICMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _LOGICMANAGER_REQ.fields_by_name['put_rule_req'])
_LOGICMANAGER_REQ.fields_by_name['put_rule_req'].containing_oneof = _LOGICMANAGER_REQ.oneofs_by_name['req']
_LOGICMANAGER_REQ.oneofs_by_name['req'].fields.append(
  _LOGICMANAGER_REQ.fields_by_name['get_rules_req'])
_LOGICMANAGER_REQ.fields_by_name['get_rules_req'].containing_oneof = _LOGICMANAGER_REQ.oneofs_by_name['req']
_LOGICMANAGER_RES.fields_by_name['get_rule_res'].message_type = _LOGICMANAGER_GETRULE_RES
_LOGICMANAGER_RES.fields_by_name['put_rule_res'].message_type = _LOGICMANAGER_PUTRULE_RES
_LOGICMANAGER_RES.fields_by_name['get_rules_res'].message_type = _LOGICMANAGER_GETRULES_RES
_LOGICMANAGER_RES.containing_type = _LOGICMANAGER
_LOGICMANAGER_RES.oneofs_by_name['res'].fields.append(
  _LOGICMANAGER_RES.fields_by_name['get_rule_res'])
_LOGICMANAGER_RES.fields_by_name['get_rule_res'].containing_oneof = _LOGICMANAGER_RES.oneofs_by_name['res']
_LOGICMANAGER_RES.oneofs_by_name['res'].fields.append(
  _LOGICMANAGER_RES.fields_by_name['put_rule_res'])
_LOGICMANAGER_RES.fields_by_name['put_rule_res'].containing_oneof = _LOGICMANAGER_RES.oneofs_by_name['res']
_LOGICMANAGER_RES.oneofs_by_name['res'].fields.append(
  _LOGICMANAGER_RES.fields_by_name['get_rules_res'])
_LOGICMANAGER_RES.fields_by_name['get_rules_res'].containing_oneof = _LOGICMANAGER_RES.oneofs_by_name['res']
_LOGICMANAGER_GETRULE_REQ.containing_type = _LOGICMANAGER_GETRULE
_LOGICMANAGER_GETRULE_RES.fields_by_name['rule'].message_type = _RULE
_LOGICMANAGER_GETRULE_RES.containing_type = _LOGICMANAGER_GETRULE
_LOGICMANAGER_GETRULE_RES.oneofs_by_name['res'].fields.append(
  _LOGICMANAGER_GETRULE_RES.fields_by_name['rule'])
_LOGICMANAGER_GETRULE_RES.fields_by_name['rule'].containing_oneof = _LOGICMANAGER_GETRULE_RES.oneofs_by_name['res']
_LOGICMANAGER_GETRULE.containing_type = _LOGICMANAGER
_LOGICMANAGER_PUTRULE_REQ.containing_type = _LOGICMANAGER_PUTRULE
_LOGICMANAGER_PUTRULE_RES.fields_by_name['rule'].message_type = _RULE
_LOGICMANAGER_PUTRULE_RES.containing_type = _LOGICMANAGER_PUTRULE
_LOGICMANAGER_PUTRULE.containing_type = _LOGICMANAGER
_LOGICMANAGER_GETRULES_REQ.containing_type = _LOGICMANAGER_GETRULES
_LOGICMANAGER_GETRULES_RES.fields_by_name['rules'].message_type = _RULE
_LOGICMANAGER_GETRULES_RES.containing_type = _LOGICMANAGER_GETRULES
_LOGICMANAGER_GETRULES.containing_type = _LOGICMANAGER
_RULE_REQ.fields_by_name['rule_delete_req'].message_type = _RULE_DELETE_REQ
_RULE_REQ.fields_by_name['rule_set_label_req'].message_type = _RULE_SETLABEL_REQ
_RULE_REQ.containing_type = _RULE
_RULE_REQ.oneofs_by_name['req'].fields.append(
  _RULE_REQ.fields_by_name['rule_delete_req'])
_RULE_REQ.fields_by_name['rule_delete_req'].containing_oneof = _RULE_REQ.oneofs_by_name['req']
_RULE_REQ.oneofs_by_name['req'].fields.append(
  _RULE_REQ.fields_by_name['rule_set_label_req'])
_RULE_REQ.fields_by_name['rule_set_label_req'].containing_oneof = _RULE_REQ.oneofs_by_name['req']
_RULE_RES.fields_by_name['rule_delete_res'].message_type = _RULE_DELETE_RES
_RULE_RES.fields_by_name['rule_set_label_res'].message_type = _RULE_SETLABEL_RES
_RULE_RES.containing_type = _RULE
_RULE_RES.oneofs_by_name['res'].fields.append(
  _RULE_RES.fields_by_name['rule_delete_res'])
_RULE_RES.fields_by_name['rule_delete_res'].containing_oneof = _RULE_RES.oneofs_by_name['res']
_RULE_RES.oneofs_by_name['res'].fields.append(
  _RULE_RES.fields_by_name['rule_set_label_res'])
_RULE_RES.fields_by_name['rule_set_label_res'].containing_oneof = _RULE_RES.oneofs_by_name['res']
_RULE_DELETE_REQ.containing_type = _RULE_DELETE
_RULE_DELETE_RES.containing_type = _RULE_DELETE
_RULE_DELETE.containing_type = _RULE
_RULE_SETLABEL_REQ.containing_type = _RULE_SETLABEL
_RULE_SETLABEL_RES.containing_type = _RULE_SETLABEL
_RULE_SETLABEL.containing_type = _RULE
DESCRIPTOR.message_types_by_name['LogicManager'] = _LOGICMANAGER
DESCRIPTOR.message_types_by_name['Rule'] = _RULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogicManager = _reflection.GeneratedProtocolMessageType('LogicManager', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _LOGICMANAGER_REQ,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _LOGICMANAGER_RES,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.Res)
    ))
  ,

  GetRule = _reflection.GeneratedProtocolMessageType('GetRule', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _LOGICMANAGER_GETRULE_REQ,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.GetRule.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _LOGICMANAGER_GETRULE_RES,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.GetRule.Res)
      ))
    ,
    DESCRIPTOR = _LOGICMANAGER_GETRULE,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.GetRule)
    ))
  ,

  PutRule = _reflection.GeneratedProtocolMessageType('PutRule', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _LOGICMANAGER_PUTRULE_REQ,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.PutRule.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _LOGICMANAGER_PUTRULE_RES,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.PutRule.Res)
      ))
    ,
    DESCRIPTOR = _LOGICMANAGER_PUTRULE,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.PutRule)
    ))
  ,

  GetRules = _reflection.GeneratedProtocolMessageType('GetRules', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _LOGICMANAGER_GETRULES_REQ,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.GetRules.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _LOGICMANAGER_GETRULES_RES,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.GetRules.Res)
      ))
    ,
    DESCRIPTOR = _LOGICMANAGER_GETRULES,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager.GetRules)
    ))
  ,
  DESCRIPTOR = _LOGICMANAGER,
  __module__ = 'protobuf.logic_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.LogicManager)
  ))
_sym_db.RegisterMessage(LogicManager)
_sym_db.RegisterMessage(LogicManager.Req)
_sym_db.RegisterMessage(LogicManager.Res)
_sym_db.RegisterMessage(LogicManager.GetRule)
_sym_db.RegisterMessage(LogicManager.GetRule.Req)
_sym_db.RegisterMessage(LogicManager.GetRule.Res)
_sym_db.RegisterMessage(LogicManager.PutRule)
_sym_db.RegisterMessage(LogicManager.PutRule.Req)
_sym_db.RegisterMessage(LogicManager.PutRule.Res)
_sym_db.RegisterMessage(LogicManager.GetRules)
_sym_db.RegisterMessage(LogicManager.GetRules.Req)
_sym_db.RegisterMessage(LogicManager.GetRules.Res)

Rule = _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _RULE_REQ,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _RULE_RES,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.Res)
    ))
  ,

  Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RULE_DELETE_REQ,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.Delete.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RULE_DELETE_RES,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.Delete.Res)
      ))
    ,
    DESCRIPTOR = _RULE_DELETE,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.Delete)
    ))
  ,

  SetLabel = _reflection.GeneratedProtocolMessageType('SetLabel', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _RULE_SETLABEL_REQ,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.SetLabel.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _RULE_SETLABEL_RES,
      __module__ = 'protobuf.logic_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.SetLabel.Res)
      ))
    ,
    DESCRIPTOR = _RULE_SETLABEL,
    __module__ = 'protobuf.logic_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Rule.SetLabel)
    ))
  ,
  DESCRIPTOR = _RULE,
  __module__ = 'protobuf.logic_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Rule)
  ))
_sym_db.RegisterMessage(Rule)
_sym_db.RegisterMessage(Rule.Req)
_sym_db.RegisterMessage(Rule.Res)
_sym_db.RegisterMessage(Rule.Delete)
_sym_db.RegisterMessage(Rule.Delete.Req)
_sym_db.RegisterMessage(Rule.Delete.Res)
_sym_db.RegisterMessage(Rule.SetLabel)
_sym_db.RegisterMessage(Rule.SetLabel.Req)
_sym_db.RegisterMessage(Rule.SetLabel.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/answer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import concept_pb2 as protobuf_dot_concept__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/answer.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\013AnswerProto'),
  serialized_pb=_b('\n\x15protobuf/answer.proto\x12\x0egrakn.protocol\x1a\x16protobuf/concept.proto\"\xae\x01\n\nConceptMap\x12\x35\n\x03map\x18\x01 \x03(\x0b\x32#.grakn.protocol.ConceptMap.MapEntryR\x03map\x12\x18\n\x07pattern\x18\x02 \x01(\tR\x07pattern\x1aO\n\x08MapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.grakn.protocol.ConceptR\x05value:\x02\x38\x01\"\x7f\n\x0f\x43onceptMapGroup\x12-\n\x05owner\x18\x01 \x01(\x0b\x32\x17.grakn.protocol.ConceptR\x05owner\x12=\n\x0c\x63oncept_maps\x18\x02 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x0b\x63onceptMaps\"l\n\x07Numeric\x12\x1f\n\nlong_value\x18\x01 \x01(\x03H\x00R\tlongValue\x12#\n\x0c\x64ouble_value\x18\x02 \x01(\x01H\x00R\x0b\x64oubleValue\x12\x12\n\x03nan\x18\x03 \x01(\x08H\x00R\x03nanB\x07\n\x05value\"n\n\x0cNumericGroup\x12-\n\x05owner\x18\x01 \x01(\x0b\x32\x17.grakn.protocol.ConceptR\x05owner\x12/\n\x06number\x18\x02 \x01(\x0b\x32\x17.grakn.protocol.NumericR\x06numberB\x1d\n\x0egrakn.protocolB\x0b\x41nswerProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_concept__pb2.DESCRIPTOR,])




_CONCEPTMAP_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='grakn.protocol.ConceptMap.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grakn.protocol.ConceptMap.MapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grakn.protocol.ConceptMap.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=240,
)

_CONCEPTMAP = _descriptor.Descriptor(
  name='ConceptMap',
  full_name='grakn.protocol.ConceptMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='grakn.protocol.ConceptMap.map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='map', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='grakn.protocol.ConceptMap.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pattern', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONCEPTMAP_MAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=240,
)


_CONCEPTMAPGROUP = _descriptor.Descriptor(
  name='ConceptMapGroup',
  full_name='grakn.protocol.ConceptMapGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='grakn.protocol.ConceptMapGroup.owner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='owner', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_maps', full_name='grakn.protocol.ConceptMapGroup.concept_maps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='conceptMaps', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=369,
)


_NUMERIC = _descriptor.Descriptor(
  name='Numeric',
  full_name='grakn.protocol.Numeric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='long_value', full_name='grakn.protocol.Numeric.long_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='longValue', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='grakn.protocol.Numeric.double_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='doubleValue', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nan', full_name='grakn.protocol.Numeric.nan', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nan', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='grakn.protocol.Numeric.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=371,
  serialized_end=479,
)


_NUMERICGROUP = _descriptor.Descriptor(
  name='NumericGroup',
  full_name='grakn.protocol.NumericGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='grakn.protocol.NumericGroup.owner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='owner', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number', full_name='grakn.protocol.NumericGroup.number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='number', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=591,
)

_CONCEPTMAP_MAPENTRY.fields_by_name['value'].message_type = protobuf_dot_concept__pb2._CONCEPT
_CONCEPTMAP_MAPENTRY.containing_type = _CONCEPTMAP
_CONCEPTMAP.fields_by_name['map'].message_type = _CONCEPTMAP_MAPENTRY
_CONCEPTMAPGROUP.fields_by_name['owner'].message_type = protobuf_dot_concept__pb2._CONCEPT
_CONCEPTMAPGROUP.fields_by_name['concept_maps'].message_type = _CONCEPTMAP
_NUMERIC.oneofs_by_name['value'].fields.append(
  _NUMERIC.fields_by_name['long_value'])
_NUMERIC.fields_by_name['long_value'].containing_oneof = _NUMERIC.oneofs_by_name['value']
_NUMERIC.oneofs_by_name['value'].fields.append(
  _NUMERIC.fields_by_name['double_value'])
_NUMERIC.fields_by_name['double_value'].containing_oneof = _NUMERIC.oneofs_by_name['value']
_NUMERIC.oneofs_by_name['value'].fields.append(
  _NUMERIC.fields_by_name['nan'])
_NUMERIC.fields_by_name['nan'].containing_oneof = _NUMERIC.oneofs_by_name['value']
_NUMERICGROUP.fields_by_name['owner'].message_type = protobuf_dot_concept__pb2._CONCEPT
_NUMERICGROUP.fields_by_name['number'].message_type = _NUMERIC
DESCRIPTOR.message_types_by_name['ConceptMap'] = _CONCEPTMAP
DESCRIPTOR.message_types_by_name['ConceptMapGroup'] = _CONCEPTMAPGROUP
DESCRIPTOR.message_types_by_name['Numeric'] = _NUMERIC
DESCRIPTOR.message_types_by_name['NumericGroup'] = _NUMERICGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConceptMap = _reflection.GeneratedProtocolMessageType('ConceptMap', (_message.Message,), dict(

  MapEntry = _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONCEPTMAP_MAPENTRY,
    __module__ = 'protobuf.answer_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptMap.MapEntry)
    ))
  ,
  DESCRIPTOR = _CONCEPTMAP,
  __module__ = 'protobuf.answer_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptMap)
  ))
_sym_db.RegisterMessage(ConceptMap)
_sym_db.RegisterMessage(ConceptMap.MapEntry)

ConceptMapGroup = _reflection.GeneratedProtocolMessageType('ConceptMapGroup', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPTMAPGROUP,
  __module__ = 'protobuf.answer_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.ConceptMapGroup)
  ))
_sym_db.RegisterMessage(ConceptMapGroup)

Numeric = _reflection.GeneratedProtocolMessageType('Numeric', (_message.Message,), dict(
  DESCRIPTOR = _NUMERIC,
  __module__ = 'protobuf.answer_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Numeric)
  ))
_sym_db.RegisterMessage(Numeric)

NumericGroup = _reflection.GeneratedProtocolMessageType('NumericGroup', (_message.Message,), dict(
  DESCRIPTOR = _NUMERICGROUP,
  __module__ = 'protobuf.answer_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.NumericGroup)
  ))
_sym_db.RegisterMessage(NumericGroup)


DESCRIPTOR._options = None
_CONCEPTMAP_MAPENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grakn_protocol.protobuf.cluster import cluster_pb2 as protobuf_dot_cluster_dot_cluster__pb2
from grakn_protocol.protobuf.cluster import database_pb2 as protobuf_dot_cluster_dot_database__pb2


class GraknClusterStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.cluster_servers = channel.unary_unary(
        '/grakn.protocol.cluster.GraknCluster/cluster_servers',
        request_serializer=protobuf_dot_cluster_dot_cluster__pb2.Cluster.Servers.Req.SerializeToString,
        response_deserializer=protobuf_dot_cluster_dot_cluster__pb2.Cluster.Servers.Res.FromString,
        )
    self.database_get = channel.unary_unary(
        '/grakn.protocol.cluster.GraknCluster/database_get',
        request_serializer=protobuf_dot_cluster_dot_database__pb2.Database.Get.Req.SerializeToString,
        response_deserializer=protobuf_dot_cluster_dot_database__pb2.Database.Get.Res.FromString,
        )
    self.database_all = channel.unary_unary(
        '/grakn.protocol.cluster.GraknCluster/database_all',
        request_serializer=protobuf_dot_cluster_dot_database__pb2.Database.All.Req.SerializeToString,
        response_deserializer=protobuf_dot_cluster_dot_database__pb2.Database.All.Res.FromString,
        )


class GraknClusterServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def cluster_servers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def database_get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def database_all(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GraknClusterServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'cluster_servers': grpc.unary_unary_rpc_method_handler(
          servicer.cluster_servers,
          request_deserializer=protobuf_dot_cluster_dot_cluster__pb2.Cluster.Servers.Req.FromString,
          response_serializer=protobuf_dot_cluster_dot_cluster__pb2.Cluster.Servers.Res.SerializeToString,
      ),
      'database_get': grpc.unary_unary_rpc_method_handler(
          servicer.database_get,
          request_deserializer=protobuf_dot_cluster_dot_database__pb2.Database.Get.Req.FromString,
          response_serializer=protobuf_dot_cluster_dot_database__pb2.Database.Get.Res.SerializeToString,
      ),
      'database_all': grpc.unary_unary_rpc_method_handler(
          servicer.database_all,
          request_deserializer=protobuf_dot_cluster_dot_database__pb2.Database.All.Req.FromString,
          response_serializer=protobuf_dot_cluster_dot_database__pb2.Database.All.Res.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grakn.protocol.cluster.GraknCluster', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/options.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/options.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\014OptionsProto'),
  serialized_pb=_b('\n\x16protobuf/options.proto\x12\x0egrakn.protocol\"\xbc\x04\n\x07Options\x12\x16\n\x05infer\x18\x01 \x01(\x08H\x00R\x05infer\x12)\n\x0ftrace_inference\x18\x02 \x01(\x08H\x01R\x0etraceInference\x12\x1a\n\x07\x65xplain\x18\x03 \x01(\x08H\x02R\x07\x65xplain\x12\x1c\n\x08parallel\x18\x04 \x01(\x08H\x03R\x08parallel\x12\x1f\n\nbatch_size\x18\x05 \x01(\x05H\x04R\tbatchSize\x12\x1c\n\x08prefetch\x18\x06 \x01(\x08H\x05R\x08prefetch\x12?\n\x1bsession_idle_timeout_millis\x18\x07 \x01(\x05H\x06R\x18sessionIdleTimeoutMillis\x12L\n\"schema_lock_acquire_timeout_millis\x18\x08 \x01(\x05H\x07R\x1eschemaLockAcquireTimeoutMillis\x12*\n\x10read_any_replica\x18\t \x01(\x08H\x08R\x0ereadAnyReplicaB\x0b\n\tinfer_optB\x15\n\x13trace_inference_optB\r\n\x0b\x65xplain_optB\x0e\n\x0cparallel_optB\x10\n\x0e\x62\x61tch_size_optB\x0e\n\x0cprefetch_optB\x1a\n\x18session_idle_timeout_optB!\n\x1fschema_lock_acquire_timeout_optB\x16\n\x14read_any_replica_optB\x1e\n\x0egrakn.protocolB\x0cOptionsProtob\x06proto3')
)




_OPTIONS = _descriptor.Descriptor(
  name='Options',
  full_name='grakn.protocol.Options',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='infer', full_name='grakn.protocol.Options.infer', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='infer', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace_inference', full_name='grakn.protocol.Options.trace_inference', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='traceInference', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explain', full_name='grakn.protocol.Options.explain', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='explain', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parallel', full_name='grakn.protocol.Options.parallel', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parallel', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_size', full_name='grakn.protocol.Options.batch_size', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchSize', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefetch', full_name='grakn.protocol.Options.prefetch', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='prefetch', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_idle_timeout_millis', full_name='grakn.protocol.Options.session_idle_timeout_millis', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionIdleTimeoutMillis', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema_lock_acquire_timeout_millis', full_name='grakn.protocol.Options.schema_lock_acquire_timeout_millis', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemaLockAcquireTimeoutMillis', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_any_replica', full_name='grakn.protocol.Options.read_any_replica', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='readAnyReplica', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='infer_opt', full_name='grakn.protocol.Options.infer_opt',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='trace_inference_opt', full_name='grakn.protocol.Options.trace_inference_opt',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='explain_opt', full_name='grakn.protocol.Options.explain_opt',
      index=2, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='parallel_opt', full_name='grakn.protocol.Options.parallel_opt',
      index=3, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='batch_size_opt', full_name='grakn.protocol.Options.batch_size_opt',
      index=4, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='prefetch_opt', full_name='grakn.protocol.Options.prefetch_opt',
      index=5, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='session_idle_timeout_opt', full_name='grakn.protocol.Options.session_idle_timeout_opt',
      index=6, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='schema_lock_acquire_timeout_opt', full_name='grakn.protocol.Options.schema_lock_acquire_timeout_opt',
      index=7, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='read_any_replica_opt', full_name='grakn.protocol.Options.read_any_replica_opt',
      index=8, containing_type=None, fields=[]),
  ],
  serialized_start=43,
  serialized_end=615,
)

_OPTIONS.oneofs_by_name['infer_opt'].fields.append(
  _OPTIONS.fields_by_name['infer'])
_OPTIONS.fields_by_name['infer'].containing_oneof = _OPTIONS.oneofs_by_name['infer_opt']
_OPTIONS.oneofs_by_name['trace_inference_opt'].fields.append(
  _OPTIONS.fields_by_name['trace_inference'])
_OPTIONS.fields_by_name['trace_inference'].containing_oneof = _OPTIONS.oneofs_by_name['trace_inference_opt']
_OPTIONS.oneofs_by_name['explain_opt'].fields.append(
  _OPTIONS.fields_by_name['explain'])
_OPTIONS.fields_by_name['explain'].containing_oneof = _OPTIONS.oneofs_by_name['explain_opt']
_OPTIONS.oneofs_by_name['parallel_opt'].fields.append(
  _OPTIONS.fields_by_name['parallel'])
_OPTIONS.fields_by_name['parallel'].containing_oneof = _OPTIONS.oneofs_by_name['parallel_opt']
_OPTIONS.oneofs_by_name['batch_size_opt'].fields.append(
  _OPTIONS.fields_by_name['batch_size'])
_OPTIONS.fields_by_name['batch_size'].containing_oneof = _OPTIONS.oneofs_by_name['batch_size_opt']
_OPTIONS.oneofs_by_name['prefetch_opt'].fields.append(
  _OPTIONS.fields_by_name['prefetch'])
_OPTIONS.fields_by_name['prefetch'].containing_oneof = _OPTIONS.oneofs_by_name['prefetch_opt']
_OPTIONS.oneofs_by_name['session_idle_timeout_opt'].fields.append(
  _OPTIONS.fields_by_name['session_idle_timeout_millis'])
_OPTIONS.fields_by_name['session_idle_timeout_millis'].containing_oneof = _OPTIONS.oneofs_by_name['session_idle_timeout_opt']
_OPTIONS.oneofs_by_name['schema_lock_acquire_timeout_opt'].fields.append(
  _OPTIONS.fields_by_name['schema_lock_acquire_timeout_millis'])
_OPTIONS.fields_by_name['schema_lock_acquire_timeout_millis'].containing_oneof = _OPTIONS.oneofs_by_name['schema_lock_acquire_timeout_opt']
_OPTIONS.oneofs_by_name['read_any_replica_opt'].fields.append(
  _OPTIONS.fields_by_name['read_any_replica'])
_OPTIONS.fields_by_name['read_any_replica'].containing_oneof = _OPTIONS.oneofs_by_name['read_any_replica_opt']
DESCRIPTOR.message_types_by_name['Options'] = _OPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Options = _reflection.GeneratedProtocolMessageType('Options', (_message.Message,), dict(
  DESCRIPTOR = _OPTIONS,
  __module__ = 'protobuf.options_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Options)
  ))
_sym_db.RegisterMessage(Options)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/database.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/database.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\rDatabaseProto'),
  serialized_pb=_b('\n\x17protobuf/database.proto\x12\x0egrakn.protocol\"\xd7\x01\n\x08\x44\x61tabase\x1aH\n\x08\x43ontains\x1a\x19\n\x03Req\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1a!\n\x03Res\x12\x1a\n\x08\x63ontains\x18\x01 \x01(\x08R\x08\x63ontains\x1a*\n\x06\x43reate\x1a\x19\n\x03Req\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1a\x05\n\x03Res\x1a)\n\x03\x41ll\x1a\x05\n\x03Req\x1a\x1b\n\x03Res\x12\x14\n\x05names\x18\x01 \x03(\tR\x05names\x1a*\n\x06\x44\x65lete\x1a\x19\n\x03Req\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1a\x05\n\x03ResB\x1f\n\x0egrakn.protocolB\rDatabaseProtob\x06proto3')
)




_DATABASE_CONTAINS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Database.Contains.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.Database.Contains.Req.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=93,
)

_DATABASE_CONTAINS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Database.Contains.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contains', full_name='grakn.protocol.Database.Contains.Res.contains', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='contains', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=128,
)

_DATABASE_CONTAINS = _descriptor.Descriptor(
  name='Contains',
  full_name='grakn.protocol.Database.Contains',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_CONTAINS_REQ, _DATABASE_CONTAINS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=128,
)

_DATABASE_CREATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Database.Create.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.Database.Create.Req.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=93,
)

_DATABASE_CREATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Database.Create.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=100,
)

_DATABASE_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='grakn.protocol.Database.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_CREATE_REQ, _DATABASE_CREATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=172,
)

_DATABASE_ALL_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Database.All.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=73,
)

_DATABASE_ALL_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Database.All.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='grakn.protocol.Database.All.Res.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='names', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=215,
)

_DATABASE_ALL = _descriptor.Descriptor(
  name='All',
  full_name='grakn.protocol.Database.All',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_ALL_REQ, _DATABASE_ALL_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=215,
)

_DATABASE_DELETE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Database.Delete.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.Database.Delete.Req.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=93,
)

_DATABASE_DELETE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Database.Delete.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=100,
)

_DATABASE_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='grakn.protocol.Database.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_DELETE_REQ, _DATABASE_DELETE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=259,
)

_DATABASE = _descriptor.Descriptor(
  name='Database',
  full_name='grakn.protocol.Database',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_CONTAINS, _DATABASE_CREATE, _DATABASE_ALL, _DATABASE_DELETE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=259,
)

_DATABASE_CONTAINS_REQ.containing_type = _DATABASE_CONTAINS
_DATABASE_CONTAINS_RES.containing_type = _DATABASE_CONTAINS
_DATABASE_CONTAINS.containing_type = _DATABASE
_DATABASE_CREATE_REQ.containing_type = _DATABASE_CREATE
_DATABASE_CREATE_RES.containing_type = _DATABASE_CREATE
_DATABASE_CREATE.containing_type = _DATABASE
_DATABASE_ALL_REQ.containing_type = _DATABASE_ALL
_DATABASE_ALL_RES.containing_type = _DATABASE_ALL
_DATABASE_ALL.containing_type = _DATABASE
_DATABASE_DELETE_REQ.containing_type = _DATABASE_DELETE
_DATABASE_DELETE_RES.containing_type = _DATABASE_DELETE
_DATABASE_DELETE.containing_type = _DATABASE
DESCRIPTOR.message_types_by_name['Database'] = _DATABASE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Database = _reflection.GeneratedProtocolMessageType('Database', (_message.Message,), dict(

  Contains = _reflection.GeneratedProtocolMessageType('Contains', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_CONTAINS_REQ,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Contains.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_CONTAINS_RES,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Contains.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_CONTAINS,
    __module__ = 'protobuf.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Contains)
    ))
  ,

  Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_CREATE_REQ,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Create.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_CREATE_RES,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Create.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_CREATE,
    __module__ = 'protobuf.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Create)
    ))
  ,

  All = _reflection.GeneratedProtocolMessageType('All', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_ALL_REQ,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.All.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_ALL_RES,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.All.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_ALL,
    __module__ = 'protobuf.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Database.All)
    ))
  ,

  Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_DELETE_REQ,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Delete.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_DELETE_RES,
      __module__ = 'protobuf.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Delete.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_DELETE,
    __module__ = 'protobuf.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Database.Delete)
    ))
  ,
  DESCRIPTOR = _DATABASE,
  __module__ = 'protobuf.database_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Database)
  ))
_sym_db.RegisterMessage(Database)
_sym_db.RegisterMessage(Database.Contains)
_sym_db.RegisterMessage(Database.Contains.Req)
_sym_db.RegisterMessage(Database.Contains.Res)
_sym_db.RegisterMessage(Database.Create)
_sym_db.RegisterMessage(Database.Create.Req)
_sym_db.RegisterMessage(Database.Create.Res)
_sym_db.RegisterMessage(Database.All)
_sym_db.RegisterMessage(Database.All.Req)
_sym_db.RegisterMessage(Database.All.Res)
_sym_db.RegisterMessage(Database.Delete)
_sym_db.RegisterMessage(Database.Delete.Req)
_sym_db.RegisterMessage(Database.Delete.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/grakn.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import database_pb2 as protobuf_dot_database__pb2
from grakn_protocol.protobuf import session_pb2 as protobuf_dot_session__pb2
from grakn_protocol.protobuf import transaction_pb2 as protobuf_dot_transaction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/grakn.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\nGraknProto'),
  serialized_pb=_b('\n\x14protobuf/grakn.proto\x12\x0egrakn.protocol\x1a\x17protobuf/database.proto\x1a\x16protobuf/session.proto\x1a\x1aprotobuf/transaction.proto2\xcf\x05\n\x05Grakn\x12\x61\n\x11\x64\x61tabase_contains\x12%.grakn.protocol.Database.Contains.Req\x1a%.grakn.protocol.Database.Contains.Res\x12[\n\x0f\x64\x61tabase_create\x12#.grakn.protocol.Database.Create.Req\x1a#.grakn.protocol.Database.Create.Res\x12R\n\x0c\x64\x61tabase_all\x12 .grakn.protocol.Database.All.Req\x1a .grakn.protocol.Database.All.Res\x12[\n\x0f\x64\x61tabase_delete\x12#.grakn.protocol.Database.Delete.Req\x1a#.grakn.protocol.Database.Delete.Res\x12R\n\x0csession_open\x12 .grakn.protocol.Session.Open.Req\x1a .grakn.protocol.Session.Open.Res\x12U\n\rsession_close\x12!.grakn.protocol.Session.Close.Req\x1a!.grakn.protocol.Session.Close.Res\x12U\n\rsession_pulse\x12!.grakn.protocol.Session.Pulse.Req\x1a!.grakn.protocol.Session.Pulse.Res\x12S\n\x0btransaction\x12\x1f.grakn.protocol.Transaction.Req\x1a\x1f.grakn.protocol.Transaction.Res(\x01\x30\x01\x42\x1c\n\x0egrakn.protocolB\nGraknProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_database__pb2.DESCRIPTOR,protobuf_dot_session__pb2.DESCRIPTOR,protobuf_dot_transaction__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_GRAKN = _descriptor.ServiceDescriptor(
  name='Grakn',
  full_name='grakn.protocol.Grakn',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=118,
  serialized_end=837,
  methods=[
  _descriptor.MethodDescriptor(
    name='database_contains',
    full_name='grakn.protocol.Grakn.database_contains',
    index=0,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_CONTAINS_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_CONTAINS_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_create',
    full_name='grakn.protocol.Grakn.database_create',
    index=1,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_CREATE_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_CREATE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_all',
    full_name='grakn.protocol.Grakn.database_all',
    index=2,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_ALL_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_ALL_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_delete',
    full_name='grakn.protocol.Grakn.database_delete',
    index=3,
    containing_service=None,
    input_type=protobuf_dot_database__pb2._DATABASE_DELETE_REQ,
    output_type=protobuf_dot_database__pb2._DATABASE_DELETE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='session_open',
    full_name='grakn.protocol.Grakn.session_open',
    index=4,
    containing_service=None,
    input_type=protobuf_dot_session__pb2._SESSION_OPEN_REQ,
    output_type=protobuf_dot_session__pb2._SESSION_OPEN_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='session_close',
    full_name='grakn.protocol.Grakn.session_close',
    index=5,
    containing_service=None,
    input_type=protobuf_dot_session__pb2._SESSION_CLOSE_REQ,
    output_type=protobuf_dot_session__pb2._SESSION_CLOSE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='session_pulse',
    full_name='grakn.protocol.Grakn.session_pulse',
    index=6,
    containing_service=None,
    input_type=protobuf_dot_session__pb2._SESSION_PULSE_REQ,
    output_type=protobuf_dot_session__pb2._SESSION_PULSE_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='transaction',
    full_name='grakn.protocol.Grakn.transaction',
    index=7,
    containing_service=None,
    input_type=protobuf_dot_transaction__pb2._TRANSACTION_REQ,
    output_type=protobuf_dot_transaction__pb2._TRANSACTION_RES,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRAKN)

DESCRIPTOR.services_by_name['Grakn'] = _GRAKN

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/cluster/database.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/cluster/database.proto',
  package='grakn.protocol.cluster',
  syntax='proto3',
  serialized_options=_b('\n\026grakn.protocol.clusterB\rDatabaseProto'),
  serialized_pb=_b('\n\x1fprotobuf/cluster/database.proto\x12\x16grakn.protocol.cluster\"\xa5\x03\n\x08\x44\x61tabase\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x08replicas\x18\x02 \x03(\x0b\x32(.grakn.protocol.cluster.Database.ReplicaR\x08replicas\x1a\x82\x01\n\x07Replica\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x18\n\x07primary\x18\x02 \x01(\x08R\x07primary\x12/\n\x13preferred_secondary\x18\x03 \x01(\x08R\x12preferredSecondary\x12\x12\n\x04term\x18\x04 \x01(\x03R\x04term\x1a\x65\n\x03Get\x1a\x19\n\x03Req\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x1a\x43\n\x03Res\x12<\n\x08\x64\x61tabase\x18\x01 \x01(\x0b\x32 .grakn.protocol.cluster.DatabaseR\x08\x64\x61tabase\x1aS\n\x03\x41ll\x1a\x05\n\x03Req\x1a\x45\n\x03Res\x12>\n\tdatabases\x18\x01 \x03(\x0b\x32 .grakn.protocol.cluster.DatabaseR\tdatabasesB\'\n\x16grakn.protocol.clusterB\rDatabaseProtob\x06proto3')
)




_DATABASE_REPLICA = _descriptor.Descriptor(
  name='Replica',
  full_name='grakn.protocol.cluster.Database.Replica',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='grakn.protocol.cluster.Database.Replica.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary', full_name='grakn.protocol.cluster.Database.Replica.primary', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='primary', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_secondary', full_name='grakn.protocol.cluster.Database.Replica.preferred_secondary', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='preferredSecondary', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='term', full_name='grakn.protocol.cluster.Database.Replica.term', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='term', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=293,
)

_DATABASE_GET_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.cluster.Database.Get.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.cluster.Database.Get.Req.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=327,
)

_DATABASE_GET_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.cluster.Database.Get.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='grakn.protocol.cluster.Database.Get.Res.database', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=396,
)

_DATABASE_GET = _descriptor.Descriptor(
  name='Get',
  full_name='grakn.protocol.cluster.Database.Get',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_GET_REQ, _DATABASE_GET_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=396,
)

_DATABASE_ALL_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.cluster.Database.All.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=307,
)

_DATABASE_ALL_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.cluster.Database.All.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='grakn.protocol.cluster.Database.All.Res.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='databases', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=481,
)

_DATABASE_ALL = _descriptor.Descriptor(
  name='All',
  full_name='grakn.protocol.cluster.Database.All',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_ALL_REQ, _DATABASE_ALL_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=481,
)

_DATABASE = _descriptor.Descriptor(
  name='Database',
  full_name='grakn.protocol.cluster.Database',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grakn.protocol.cluster.Database.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replicas', full_name='grakn.protocol.cluster.Database.replicas', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='replicas', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATABASE_REPLICA, _DATABASE_GET, _DATABASE_ALL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=481,
)

_DATABASE_REPLICA.containing_type = _DATABASE
_DATABASE_GET_REQ.containing_type = _DATABASE_GET
_DATABASE_GET_RES.fields_by_name['database'].message_type = _DATABASE
_DATABASE_GET_RES.containing_type = _DATABASE_GET
_DATABASE_GET.containing_type = _DATABASE
_DATABASE_ALL_REQ.containing_type = _DATABASE_ALL
_DATABASE_ALL_RES.fields_by_name['databases'].message_type = _DATABASE
_DATABASE_ALL_RES.containing_type = _DATABASE_ALL
_DATABASE_ALL.containing_type = _DATABASE
_DATABASE.fields_by_name['replicas'].message_type = _DATABASE_REPLICA
DESCRIPTOR.message_types_by_name['Database'] = _DATABASE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Database = _reflection.GeneratedProtocolMessageType('Database', (_message.Message,), dict(

  Replica = _reflection.GeneratedProtocolMessageType('Replica', (_message.Message,), dict(
    DESCRIPTOR = _DATABASE_REPLICA,
    __module__ = 'protobuf.cluster.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Replica)
    ))
  ,

  Get = _reflection.GeneratedProtocolMessageType('Get', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_GET_REQ,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Get.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_GET_RES,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Get.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_GET,
    __module__ = 'protobuf.cluster.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.Get)
    ))
  ,

  All = _reflection.GeneratedProtocolMessageType('All', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_ALL_REQ,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.All.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _DATABASE_ALL_RES,
      __module__ = 'protobuf.cluster.database_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.All.Res)
      ))
    ,
    DESCRIPTOR = _DATABASE_ALL,
    __module__ = 'protobuf.cluster.database_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database.All)
    ))
  ,
  DESCRIPTOR = _DATABASE,
  __module__ = 'protobuf.cluster.database_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Database)
  ))
_sym_db.RegisterMessage(Database)
_sym_db.RegisterMessage(Database.Replica)
_sym_db.RegisterMessage(Database.Get)
_sym_db.RegisterMessage(Database.Get.Req)
_sym_db.RegisterMessage(Database.Get.Res)
_sym_db.RegisterMessage(Database.All)
_sym_db.RegisterMessage(Database.All.Req)
_sym_db.RegisterMessage(Database.All.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
